Development — BCI-Framework documentation

# Development

This environment use the integrated development environt to code a test new extensions.

class `bci_framework.framework.environments.development.` `Development`(core)

  Main Action with an integrated development environ.

  `__init__`(core)

    Constructor

  `build_linenumber`() → None

    The same linenumber is used for all editors.

  `build_preview`() → None

    Update mdiAreas.

  `connect`() → None

    Connect events.

  `get_project`() → Path

    Return the path of the current project.

  `hide_preview`() → None

    Expand editor.

  `on_focus`() → None

    Set the correct projects widget.

  `open_subwindow`() → None

    Open an auxiliar window for stimuli delivery.

  `save_all_files`() → None

    Save all opened files.

  `show_preview`() → None

    Show previsualization.

  `start_preview`() → None

    Initialize the previsualization and the debugger.

  `stop_preview`() → None

    Stop subprocess.

  `update_log`() → None

    Write logs into debugger.

    Logging messages could be from Python or JavaScript (Bryhon).